@@ -1,20 +1,13 @@
 # This file is part of ReText
-# Copyright: Dmitry Shachnev 2012
+# Copyright: Dmitry Shachnev 2012-2014
 # License: GNU GPL v2 or higher
 
 import os
 import sys
 import shutil
+from glob import glob1
 from functools import wraps
 from markups.web import WebLibrary
-from ReText import app_version
-
-app_name = "ReText Webpages generator"
-app_data = (
-	app_name,
-	app_version,
-	"http://sourceforge.net/p/retext/"
-)
 
 templatesDir = os.path.abspath(os.path.dirname(sys.argv[0])) + "/templates/"
 if not os.path.exists(templatesDir):
@@ -40,13 +33,13 @@ def wpInit():
 
 @handleErrors
 def wpUpdate(pages):
-	wl = WebLibrary(app_data=app_data)
+	wl = WebLibrary()
 	for page in pages:
 		wl.update(page)
 
 @handleErrors
 def wpUpdateAll():
-	wl = WebLibrary(app_data=app_data)
+	wl = WebLibrary()
 	wl.update_all()
 
 def wpUseStyle(styleName):
@@ -55,4 +48,8 @@ def wpUseStyle(styleName):
 			os.mkdir("html")
 		shutil.copy(templatesDir+"style_%s.css" % styleName, "html/style.css")
 	else:
-		print('Error: no such file!')
+		print('Error: no such style!', file=sys.stderr)
+
+def wpListStyles():
+	for fileName in glob1(templatesDir, "style_*.css"):
+		print(fileName[6:-4])
