@@ -6,6 +6,7 @@
 import markups
 import sys
 from subprocess import Popen
+from markups.common import MODULE_HOME_PAGE
 from ReText import icon_path, DOCTYPE_MARKDOWN, DOCTYPE_REST, app_name, \
  app_version, globalSettings, settings, readListFromSettings, \
  writeListToSettings, writeToSettings, datadirs, enchant, enchant_available
@@ -24,6 +25,7 @@ from PyQt5.QtWidgets import QAction, QActionGroup, QApplication, QCheckBox, \
  QLineEdit, QMainWindow, QMenuBar, QMessageBox, QSplitter, QTabWidget, \
  QTextBrowser, QTextEdit, QToolBar
 from PyQt5.QtPrintSupport import QPrintDialog, QPrintPreviewDialog, QPrinter
+from PyQt5.QtWebKit import QWebSettings
 from PyQt5.QtWebKitWidgets import QWebPage, QWebView
 
 class ReTextWindow(QMainWindow):
@@ -383,6 +385,7 @@ class ReTextWindow(QMainWindow):
 		if not globalSettings.handleWebLinks:
 			webView.page().setLinkDelegationPolicy(QWebPage.DelegateExternalLinks)
 			webView.page().linkClicked.connect(QDesktopServices.openUrl)
+		webView.settings().setAttribute(QWebSettings.LocalContentCanAccessFileUrls, False)
 		return webView
 
 	def createTab(self, fileName):
@@ -639,7 +642,7 @@ class ReTextWindow(QMainWindow):
 			errMsg = self.tr('Could not parse file contents, check if '
 			'you have the <a href="%s">necessary module</a> installed!')
 			try:
-				errMsg %= markupClass.attributes[markups.MODULE_HOME_PAGE]
+				errMsg %= markupClass.attributes[MODULE_HOME_PAGE]
 			except (AttributeError, KeyError):
 				# Remove the link if markupClass doesn't have the needed attribute
 				errMsg = errMsg.replace('<a href="%s">', '')
